# pylingdocs-gui

![License](https://img.shields.io/github/license/fmatter/pylingdocs-gui)
[![Linting](https://img.shields.io/github/workflow/status/fmatter/pylingdocs-gui/lint?label=linting)](https://github.com/fmatter/pylingdocs-gui/actions/workflows/lint.yml)
[![PyPI](https://img.shields.io/pypi/v/pylingdocs-gui.svg)](https://pypi.org/project/pylingdocs-gui)
![Versions](https://img.shields.io/pypi/pyversions/pylingdocs-gui)

A rudimentary GUI editor for pylingdocs.

* Installation: `pip install pylingdocs-gui`
* Usage: run `pylingdocs-gui` in your pylingdocs project

![Screenshot from 2022-09-22 10-13-03](https://user-images.githubusercontent.com/2378389/191810571-90272c83-37e3-408a-b7ee-4983a23cbef0.png)
